/* 8BitAmEthernet
 * version 0.3.1 date 2006-03-12
 * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
 * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
 * a project of CCC-AC - http://www.cccac.de/
 */

#ifndef INC_random
#define INC_random

//provide some entropy
extern void RandomProvideEntropy( unsigned char Entropy );

//task function to do the work - call from main loop
extern void RandomTask( void );

//get random data
extern void RandomGetData( unsigned char * pData, unsigned char Length );

#endif //#ifndef INC_random
